@@ -29,7 +29,7 @@ def install_excepthook(app_name,app_version):
 
     def my_excepthook(exctype, value, tb):
         print "\n--> THE ERROR OCCURED HERE <--\n"
-        print "-----------------------------------------------------------------------------"
+        print "-------------------------------------------------"
         print "Cleanup..."
 
 #        delete_all_Alarms()
@@ -60,7 +60,7 @@ def error():
 
 #A small Qt Dialog
 def ErrorReportDialog(trace,txt_email=None):
-    print "-----------------------------------------------------------------------------\n"
+    print "-------------------------------------------------\n"
 #    item, ok = QInputDialog.getItem(None, 'Select voice type', "", "aabcde", 0, False)
     print "## Oops! An error occurred!"
     print "Below is a print out of the record data as well as the configuration:"
@@ -72,7 +72,7 @@ def ErrorReportDialog(trace,txt_email=None):
     arr=txt.split("\n")
 #    print arr
 #    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
-    txt="SleepAnalyser crashed and has to be closed.\n\n"
+    txt="SleepAnalyser crashed and has to be closed.\n\nThe error log is stored in home/user/MyDocs/SleepAnalyser/error.log\n\n"
     for i in range(len(arr)-7, len(arr)-1): txt=txt+arr[i]+"\n"
 
     QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt, QMessageBox.Ok) #Max 11 lines in dialog!
